Utilities APIs.
Re-exports
pub use ::bytes;pub use ::serde as ser;pub use ::serde_json as json;pub use ::lazy_regex as regex;pub use ::chrono as temporal;pub use ::file_paths as paths;pub use ::oop_inheritance as inheritance;
Modules
- Literals for standard library collections.
- Work with URIs.
Macros
- The main macro provided by this crate. See crate documentation for more information.
- Initializes a structure without specifying its name.
Structs
- Wrapper for pointer types that implements by-address comparison.
- Represents a color containing red, green, blue and alpha channels.
- Represents red, green, blue and alpha offsets in the range between -255 and 255.
- Error resulted from parsing a
Colorfrom a string. - A value which is initialized on the first access.
Traits
- The
LateFormattrait allows substituting string parameters of arbitrary name that is computed at runtime. - Provides additional methods for the standard
Vec<T>type.
Functions
- Returns the default value of a type.