pub struct ByAddress<T>(pub T)
where
T: Deref + ?Sized;Expand description
Wrapper for pointer types that implements by-address comparison.
See the crate-level documentation for details.
Note that equality tests and hashes on fat pointers (&dyn Trait, &[T], &str, etc)
include the attribute of the fat pointer. If this is not desired, use ByThinAddress.
Tuple Fields
0: TTrait Implementations
sourceimpl<T> PartialEq for ByAddress<T>
impl<T> PartialEq for ByAddress<T>
Raw pointer equality
sourceimpl<T> PartialOrd for ByAddress<T>
impl<T> PartialOrd for ByAddress<T>
Raw pointer comparison
1.0.0 · sourcefn le(&self, other: &Rhs) -> bool
fn le(&self, other: &Rhs) -> bool
This method tests less than or equal to (for
self and other) and is used by the <=
operator. Read moreimpl<T> Copy for ByAddress<T>
impl<T> Eq for ByAddress<T>